(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('rxjs/BehaviorSubject'), require('jquery'), require('rxjs/Observable'), require('rxjs/add/observable/timer')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', 'rxjs/BehaviorSubject', 'jquery', 'rxjs/Observable', 'rxjs/add/observable/timer'], factory) :
	(factory((global['ng2-carousel-3d'] = {}),global.core,global.common,global.BehaviorSubject,global.jqueryProxy,global.Observable));
}(this, (function (exports,core,common,BehaviorSubject,jqueryProxy,Observable) { 'use strict';

var jqueryProxy__default = jqueryProxy['default'];

var Deferred = (function () {
    function Deferred() {
        var _this = this;
        this.promise = new Promise(function (resolve, reject) {
            _this.resolve = resolve;
            _this.reject = reject;
        });
    }
    return Deferred;
}());
var Ng2Carousel3dService = (function () {
    /**
     * @param {?} slides
     * @param {?} params
     */
    function Ng2Carousel3dService(slides, params) {
        this.slides = slides || [];
        this.leftSlides = [];
        this.rightSlides = [];
        this.leftOutSlide = '';
        this.rightOutSlide = '';
        this.loadCount = 0;
        this.errorCount = 0;
        this.states = {
            PENDING: 1,
            LOADING: 2,
            RESOLVED: 3,
            REJECTED: 4
        };
        this.total = slides.length;
        this.currentIndex = 0;
        this.lock = false;
        this.loop = params.loop || false;
        this.clicking = params.clicking || false;
        this.sourceProp = params.sourceProp || '';
        this.visible = params.visible || 5;
        this.perspective = params.perspective || 35;
        this.animationSpeed = params.animationSpeed || 500;
        this.dir = params.dir || 'ltr';
        this.width = params.width || 360;
        this.height = params.height || 270;
        this.border = params.border || 0;
        this.space = params.space || 'auto';
        this.topSpace = params.topSpace || 'auto';
        this.controls = params.controls || false;
        this.startSlide = params.startSlide || 0;
        this.inverseScaling = params.inverseScaling || 300;
        this.autoRotationSpeed = params.autoRotationSpeed || 0;
        this.state = this.states.PENDING;
        this.deferred = new Deferred();
        this.promise = this.deferred.promise;
        this.percent = new BehaviorSubject.BehaviorSubject(new Object());
        this.imageLocation = new BehaviorSubject.BehaviorSubject(new Object());
    }
    /**
     * @param {?} model
     * @param {?} params
     * @return {?}
     */
    Ng2Carousel3dService.prototype.build = function (model, params) {
        var /** @type {?} */ carousel = this;
        return carousel.load().promise.then(function () {
            carousel.visible = (carousel.visible > carousel.total) ? carousel.total : carousel.visible;
            carousel.currentIndex = carousel.startSlide > carousel.total - 1 ? carousel.total - 1 : params.startSlide;
            try {
                if (carousel.visible !== 2) {
                    carousel.visible = (carousel.visible % 2) ? carousel.visible : carousel.visible - 1;
                }
            }
            catch (error) {
                console.log(error);
            }
            return carousel;
        }, function (err) { return carousel; });
    };
    
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.isInitiated = function () {
        return (this.state !== this.states.PENDING);
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.isRejected = function () {
        return (this.state === this.states.REJECTED);
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.isResolved = function () {
        return (this.state === this.states.RESOLVED);
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.load = function () {
        if (this.isInitiated()) {
            return this;
        }
        this.state = this.states.LOADING;
        if (!this.sourceProp) {
            this.deferred.resolve(this);
        }
        else {
            for (var /** @type {?} */ i = 0; i < this.total; i++) {
                this.loadImageLocation(this.slides[i]);
            }
        }
        return this;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.handleImageError = function () {
        this.errorCount++;
        if (this.isRejected()) {
            return;
        }
        this.state = this.states.REJECTED;
        this.deferred.reject(this);
    };
    /**
     * @param {?} imageLocation
     * @return {?}
     */
    Ng2Carousel3dService.prototype.handleImageLoad = function (imageLocation) {
        this.loadCount++;
        if (this.isRejected()) {
            return;
        }
        this.percent.next(new Object({ percent: Math.ceil(this.loadCount / this.total * 100) }));
        this.imageLocation.next(imageLocation);
        if (this.loadCount === this.total) {
            this.state = this.states.RESOLVED;
            this.deferred.resolve(this);
        }
    };
    /**
     * @param {?} imageLocation
     * @return {?}
     */
    Ng2Carousel3dService.prototype.loadImageLocation = function (imageLocation) {
        var /** @type {?} */ carousel = this, /** @type {?} */ image = new Image();
        image.onload = function (event) {
            carousel.handleImageLoad(event.target);
            image = event = null;
        };
        image.onerror = function (event) {
            carousel.handleImageError();
            image = event = null;
        };
        image.src = imageLocation[this.sourceProp];
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getTotalNumber = function () {
        return this.total;
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dService.prototype.setStartSlide = function (index) {
        this.startSlide = (index < 0 || index > this.total) ? 0 : index;
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dService.prototype.setCurrentIndex = function (index) {
        return this.currentIndex = index;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getOuterWidth = function () {
        return parseInt(this.width + this.border);
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getOuterHeight = function () {
        return parseInt(this.height + this.border, 10);
    };
    /**
     * @param {?} value
     * @return {?}
     */
    Ng2Carousel3dService.prototype.setLock = function (value) {
        return this.lock = value;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getLock = function () {
        return this.lock;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getSlides = function () {
        return this.slides;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.setSlides = function () {
        var /** @type {?} */ num = Number(Math.floor(this.visible / 2) + 1);
        var /** @type {?} */ dir = 'ltr';
        this.leftSlides = [];
        this.rightSlides = [];
        for (var /** @type {?} */ m = 1; m < num; m++) {
            var /** @type {?} */ eq1 = (this.dir === dir) ? (this.currentIndex + m) % (this.total) : (this.currentIndex - m) % (this.total), /** @type {?} */ eq2 = (this.dir === dir) ? (this.currentIndex - m) % (this.total) : (this.currentIndex + m) % (this.total);
            this.leftSlides.push(eq1);
            this.rightSlides.push(eq2);
        }
        var /** @type {?} */ rightOut = this.leftOutSlide = (this.currentIndex - num), /** @type {?} */ leftOut = this.rightOutSlide = ((this.total - this.currentIndex - num) <= 0) ? (-(this.total - this.currentIndex - num)) : (this.currentIndex + num);
        if (this.dir === dir) {
            this.leftOutSlide = rightOut;
            this.rightOutSlide = leftOut;
        }
        return this.slides;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getVisibleSlidesIndex = function () {
        var _this = this;
        // Build an object containing each slide number in their apparition order (even the hidden ones)
        var /** @type {?} */ visibleSlidesObj = {};
        var /** @type {?} */ value = this.currentIndex;
        var /** @type {?} */ key = Math.floor(this.total / 2);
        var /** @type {?} */ count = 0;
        while (count !== this.total) {
            visibleSlidesObj[key % this.total] = value;
            key = ++key % this.total;
            value = ++value % this.total;
            count++;
        }
        // The object looks like an array so the values are sorted
        var /** @type {?} */ visibleSlidesArr = Object.keys(visibleSlidesObj).map(function (key) { return visibleSlidesObj[key]; });
        // Takes care of the direction
        if (this.dir === 'ltr') {
            visibleSlidesArr = visibleSlidesArr.reverse();
        }
        // Extracts only the visible slides
        var /** @type {?} */ indexInTab = visibleSlidesArr.findIndex(function (val) { return val === _this.currentIndex; });
        return visibleSlidesArr.splice(indexInTab - Math.floor(this.visible / 2), this.visible);
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.isLastSlide = function () {
        return this.currentIndex === this.total - 1;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.isFirstSlide = function () {
        return this.currentIndex === 0;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getSourceProp = function () {
        return this.sourceProp;
    };
    
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getPercent = function () {
        return this.percent.asObservable();
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dService.prototype.getImageLocation = function () {
        return this.imageLocation.asObservable();
    };
    return Ng2Carousel3dService;
}());

var __assign = (undefined && undefined.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var jquery = jqueryProxy__default || jqueryProxy;
var Ng2Carousel3dComponent = (function () {
    function Ng2Carousel3dComponent() {
        this.isLoading = true;
        this.isSuccessful = false;
        this.isRendered = false;
        this.percentLoaded = 0;
        this.autoRotation = null;
        this.$wrapper = null;
        this.$slides = [];
    }
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.ngOnDestroy = function () {
        // unsubscribe to ensure no memory leaks
        this.percentSubscription.unsubscribe();
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.ngOnChanges = function (changes) {
        if (changes['slides'] && changes['options']) {
            this.buildCarousel(changes.slides.currentValue, changes.options.currentValue);
        }
        else if (changes['slides']) {
            this.buildCarousel(changes.slides.currentValue, this.options);
        }
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.ngOnInit = function () {
        this.buildCarousel(this.slides, this.options);
    };
    /**
     * @param {?} slides
     * @param {?} options
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.buildCarousel = function (slides, options) {
        var _this = this;
        this.$carouselService = new Ng2Carousel3dService(this.slides, this.options);
        this.percentSubscription = this.$carouselService.getPercent().subscribe(function (sub) { _this.percentLoaded = sub.percent; });
        this.autoRotationLocked = false;
        return this.$carouselService
            .build(this.slides || [], this.options || {})
            .then(function (carousel) {
            _this.carousel3d = carousel;
            _this.slides = _this.carousel3d.slides;
            _this.controls = _this.carousel3d.controls;
            _this.isLoading = false;
            _this.isSuccessful = true;
            var /** @type {?} */ outerHeight = _this.carousel3d.getOuterHeight(), /** @type {?} */ outerWidth = _this.carousel3d.getOuterWidth();
            jquery('div.carousel-3d-container').css({ 'height': outerHeight + 'px' });
            _this.$wrapper = jquery('div.carousel-3d');
            _this.$wrapper.css({ 'width': outerWidth + 'px', 'height': outerHeight + 'px' });
            _this.$slides = _this.$wrapper.children().toArray();
            new Promise(function (resolve, reject) {
                resolve(_this.render(true, _this.carousel3d.animationSpeed));
            }).then(function (res) {
                _this.animationEnd();
            });
        }, 
        // == Preloaded images reject  handler
        function handleReject(carousel) {
            if (this) {
                this.carousel3d = carousel;
                this.isLoading = false;
                this.isSuccessful = false;
            }
            jquery().css({ 'height': carousel.getOuterHeight() + 'px' });
        }, 
        // == Preloaded images notify handler which is executed multiple times during preload
        function handleNotify(event) {
            this.percentLoaded = event.percent;
        });
    };
    /**
     * @param {?} animate
     * @param {?} speedTime
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.render = function (animate, speedTime) {
        var _this = this;
        this.carousel3d.setSlides();
        var /** @type {?} */ outerHeight = this.carousel3d.getOuterHeight(), /** @type {?} */ outerWidth = this.carousel3d.getOuterWidth(), /** @type {?} */ slideTop = (this.carousel3d.topSpace === 'auto') ? 0 : ((outerHeight / 2) - (outerHeight / 2)), /** @type {?} */ slideLeft = ((this.carousel3d.width / 2) - (outerWidth / 2)), /** @type {?} */ speed = (speedTime) ? (speedTime / 1000) : (this.carousel3d.animationSpeed / 1000), /** @type {?} */ zIndex = 999;
        // == Set other slides styles
        this.carousel3d.slides.forEach(function (slide, index) {
            var /** @type {?} */ css = {
                position: 'absolute',
                opacity: 0,
                visibility: 'hidden',
                overflow: 'hidden',
                top: slideTop + 'px',
                'border-width': _this.carousel3d.border + 'px',
                width: outerWidth + 'px',
                height: outerHeight + 'px'
            };
            if (animate) {
                var /** @type {?} */ css2 = __assign({}, css, { '-webkit-transition': 'all ' + speed + 's ', '-moz-transition': 'all ' + speed + 's ', '-o-transition': 'all ' + speed + 's ', '-ms-transition': 'all ' + speed + 's ', 'transition': 'all ' + speed + 's ' });
                _this.getSlide(index).css(css2);
            }
            _this.getSlide(index).css(css);
        });
        // == Set first slide styles
        this.getSlide(this.carousel3d.currentIndex)
            .addClass('current')
            .css({
            zIndex: zIndex,
            opacity: 1,
            visibility: 'visible',
            '-webkit-transform': 'none',
            '-moz-transform': 'none',
            '-o-transform': 'none',
            '-ms-transform': 'none',
            'transform': 'none',
            left: slideLeft + 'px',
            top: slideTop + 'px',
            width: outerWidth + 'px',
            height: outerHeight + 'px'
        });
        this.carousel3d.rightSlides.forEach(function (slide, index) {
            var /** @type {?} */ css = _this.setCss(index, zIndex, true);
            zIndex -= index + 1;
            _this.getSlide(slide)
                .css(css)
                .css({
                opacity: 1,
                visibility: 'visible',
                zIndex: zIndex
            });
        });
        this.carousel3d.leftSlides.forEach(function (slide, index) {
            var /** @type {?} */ css = _this.setCss(index, zIndex, false);
            zIndex -= index + 1;
            _this.getSlide(slide)
                .css(css)
                .css({
                opacity: 1,
                visibility: 'visible',
                zIndex: zIndex
            });
        });
        if (this.carousel3d.total > this.carousel3d.visible) {
            var /** @type {?} */ rCSS = this.setCss(this.carousel3d.rightSlides.length - 1, this.carousel3d.rightSlides.length - 1, true), /** @type {?} */ lCSS = this.setCss(this.carousel3d.leftSlides.length - 1, this.carousel3d.leftSlides.length - 1, true);
            this.getSlide(this.carousel3d.rightOutSlide).css(rCSS);
            this.getSlide(this.carousel3d.leftOutSlide).css(lCSS);
        }
        this.isRendered = true;
        return true;
    };
    /**
     * @param {?} i
     * @param {?} zIndex
     * @param {?} positive
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.setCss = function (i, zIndex, positive) {
        var /** @type {?} */ leftRemain = (this.carousel3d.space == 'auto') ? ((i + 1) * (this.carousel3d.width / 1.5)) : ((i + 1) * (this.carousel3d.space)), /** @type {?} */ transform = (positive) ?
            'translateX(' + (leftRemain) + 'px) translateZ(-' +
                (this.carousel3d.inverseScaling + ((i + 1) * 100)) + 'px) rotateY(-' +
                this.carousel3d.perspective + 'deg)' :
            'translateX(-' + (leftRemain) + 'px) translateZ(-' +
                (this.carousel3d.inverseScaling + ((i + 1) * 100)) + 'px) rotateY(' +
                this.carousel3d.perspective + 'deg)', /** @type {?} */ left = '0%', /** @type {?} */ top = (this.carousel3d.topSpace === 'auto') ? 'none' : ((i + 1) * (this.carousel3d.space)), /** @type {?} */ width = 'none', /** @type {?} */ height = 'none', /** @type {?} */ overflow = 'visible';
        return {
            '-webkit-transform': transform,
            '-moz-transform': transform,
            '-o-transform': transform,
            '-ms-transform': transform,
            'transform': transform,
            left: left,
            top: top,
            width: width,
            height: height,
            zIndex: zIndex,
            overflow: overflow
        };
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.goSlide = function (index) {
        var _this = this;
        var /** @type {?} */ keepChanging = false;
        if (typeof this.onBeforeChange === 'function') {
            keepChanging = this.onBeforeChange({
                index: this.carousel3d.currentIndex
            });
            if (keepChanging === false) {
                return;
            }
        }
        this.carousel3d.setCurrentIndex((index < 0 || index > this.carousel3d.total - 1) ? 0 : index);
        if (this.carousel3d.isLastSlide()) {
            if (typeof this.onLastSlide === 'function') {
                this.onLastSlide({
                    index: this.carousel3d.currentIndex
                });
            }
        }
        this.$slides.forEach(function (slide, index) {
            jquery().removeClass('current');
        });
        this.carousel3d.setLock(true);
        new Promise(function (resolve, reject) {
            resolve(_this.render(true, _this.carousel3d.animationSpeed));
        }).then(function (res) {
            _this.animationEnd();
        });
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.goNext = function () {
        if (this.carousel3d.getLock() || (!this.carousel3d.loop && this.carousel3d.isLastSlide())) {
            return false;
        }
        if (this.carousel3d.isLastSlide()) {
            this.goSlide(0);
        }
        else {
            this.goSlide(this.carousel3d.currentIndex + 1);
        }
        return true;
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.goPrev = function () {
        if (this.carousel3d.getLock() || (!this.carousel3d.loop && this.carousel3d.isFirstSlide())) {
            return false;
        }
        if (this.carousel3d.isFirstSlide()) {
            this.goSlide(this.carousel3d.total - 1);
        }
        else {
            this.goSlide(this.carousel3d.currentIndex - 1);
        }
        return true;
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.goFar = function (index) {
        var _this = this;
        if (index === this.carousel3d.currentIndex) {
            return;
        }
        var /** @type {?} */ visibleSlides = this.carousel3d.getVisibleSlidesIndex();
        var /** @type {?} */ indexInVisibleSlides = visibleSlides.findIndex(function (val) { return val === index; });
        if (indexInVisibleSlides < 0) {
            return;
        }
        var /** @type {?} */ currentIndexInVisibleSlides = visibleSlides.findIndex(function (val) { return val === _this.carousel3d.currentIndex; });
        if (currentIndexInVisibleSlides < 0) {
            return;
        }
        var /** @type {?} */ diff = indexInVisibleSlides - currentIndexInVisibleSlides;
        if (this.carousel3d.dir === 'ltr') {
            diff = -diff;
        }
        var /** @type {?} */ diff2 = Math.abs(diff);
        var /** @type {?} */ timeBuff = 0;
        var /** @type {?} */ timeout = this.carousel3d.animationSpeed / diff2;
        for (var /** @type {?} */ i = 0; i < diff2; i++, timeBuff += timeout) {
            setTimeout(function () {
                if (diff >= 0) {
                    _this.goNext();
                }
                else {
                    _this.goPrev();
                }
            }, timeBuff);
        }
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.animationEnd = function () {
        this.carousel3d.setLock(false);
        if (typeof this.onSlideChange === 'function') {
            this.onSlideChange({
                index: this.carousel3d.currentIndex
            });
        }
        if (!this.$timer) {
            this.subscribe();
        }
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.getSlide = function (index) {
        return (index >= 0) ? jquery(this.$slides[index]) : jquery(this.$slides[this.carousel3d.total + index]);
    };
    /**
     * @param {?} index
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.slideClicked = function (index) {
        if (this.$timer) {
            this.$timer.unsubscribe();
        }
        this.$timer = null;
        if (this.carousel3d.currentIndex != index) {
            if (!this.carousel3d.clicking) {
                return false;
            }
            else {
                this.goFar(index);
            }
        }
        else {
            if (typeof this.onSelectedClick === 'function') {
                this.onSelectedClick({
                    index: this.carousel3d.currentIndex
                });
            }
        }
    };
    /**
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.subscribe = function () {
        var _this = this;
        this.$timer = Observable.Observable.timer(this.carousel3d.autoRotationSpeed, this.carousel3d.autoRotationSpeed).subscribe(function () {
            if (!_this.carousel3d.autoRotationLocked) {
                if (_this.options['dir'] === 'ltr') {
                    _this.goNext();
                }
                else {
                    _this.goPrev();
                }
            }
        });
    };
    /**
     * @param {?} value
     * @return {?}
     */
    Ng2Carousel3dComponent.prototype.setSlideLock = function (value) {
        this.$carouselService.setLock(value);
        this.autoRotationLocked = value;
    };
    return Ng2Carousel3dComponent;
}());
Ng2Carousel3dComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ng2-carousel-3d',
                template: "<div class=\"carousel-3d-container\"> <div class=\"carousel-3d-loader\" [hidden]=\"!isLoading\"> <div class=\"carousel-3d-loader-circle\"></div> <div class=\"carousel-3d-loader-percentage\">{{ percentLoaded }}</div> </div> <div  [hidden]=\"isLoading\" [ngSwitch]=\"isSuccessful\" > <div #carousel3D class=\"carousel-3d\" [hidden]=\"!isRendered && !isSuccessful\"> <ng-content></ng-content> </div> <p  [hidden]=\"isSuccessful\"  class=\"carousel-3d-loader-error\">There was a problem during load</p> <div *ngIf=\"controls\" class=\"carousel-3d-controls\"> <div class=\"carousel-3d-next arrow-left\" (click)=\"options.dir === 'ltr' ? goNext() : goPrev()\"></div> <div class=\"carousel-3d-prev arrow-right\" (click)=\"options.dir === 'ltr' ? goPrev() : goNext()\"></div> </div> </div> </div>",
                styles: [".carousel-3d-container { width: 100%; overflow: hidden; position: relative; z-index: 0; margin: 20px auto; } .carousel-3d { position: relative; margin: 0 auto; -webkit-transform-style: preserve-3d; -moz-transform-style: preserve-3d; -o-transform-style: preserve-3d; -ms-transform-style: preserve-3d; transform-style: preserve-3d; -webkit-perspective: 1000px; -moz-perspective: 1000px; -o-perspective: 1000px; -ms-perspective: 1000px; perspective: 1000px; } .carousel-3d.ng-hide { opacity: 0; } .carousel-3d.ng-hide-remove { transition: opacity linear 1000ms; } .carousel-3d.ng-hide-add { transition: opacity linear 500ms; } /*====================================*/ .carousel-3d-controls { position: absolute; top: 30%; left: 0; width: 100%; z-index: 9099; } .carousel-3d-next, .carousel-3d-prev { width: 60px; position: absolute !important; z-index: 9999; } .carousel-3d-next:hover, .carousel-3d-prev:hover { cursor: pointer; } .carousel-3d-next { left: 0; } .carousel-3d-prev { right: 0; } .arrow-top, .arrow-right, .arrow-bottom, .arrow-left { display: block; margin: 20px auto; overflow: hidden; position: relative; } .arrow-top, .arrow-bottom { height: 34px; width: 64px; } .arrow-right, .arrow-left { height: 64px; width: 34px; } .arrow-top:before, .arrow-right:before, .arrow-bottom:before, .arrow-left:before { border: 30px solid transparent; content: ' '; display: block; position: absolute; z-index: 2; } .arrow-top:before { border-bottom-color: #000000; left: 2px; bottom: 0; } .arrow-right:before { border-left-color: #000000; left: 0; top: 2px; } .arrow-bottom:before { border-top-color: #000000; left: 2px; top: 0; } .arrow-left:before { border-right-color: #000000; right: 0; top: 2px; } .arrow-top-bg:after, .arrow-right-bg:after, .arrow-bottom-bg:after, .arrow-left-bg:after { border: 32px solid transparent; content: ' '; display: block; position: absolute; z-index: 1; } .arrow-top-bg:after { border-bottom-color: #000000; bottom: 0; left: 0; } .arrow-right-bg:after { border-left-color: #000000; left: 0; top: 0; } .arrow-bottom-bg:after { border-top-color: #000000; left: 0; top: 0; } .arrow-left-bg:after { border-right-color: #000000; right: 0; top: 0; } /*====================================*/ @-webkit-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-webkit-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-moz-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-ms-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-moz-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-webkit-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @-o-keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } @keyframes uil-rolling-anim { 0% { -ms-transform: rotate(0deg); -moz-transform: rotate(0deg); -webkit-transform: rotate(0deg); -o-transform: rotate(0deg); transform: rotate(0deg); } 50% { -ms-transform: rotate(180deg); -moz-transform: rotate(180deg); -webkit-transform: rotate(180deg); -o-transform: rotate(180deg); transform: rotate(180deg); } 100% { -ms-transform: rotate(360deg); -moz-transform: rotate(360deg); -webkit-transform: rotate(360deg); -o-transform: rotate(360deg); transform: rotate(360deg); } } .carousel-3d-loader-circle { border: 16px solid #d9d9d9; /* Light grey */ border-top: 16px solid #209e91; /* Blue */ border-radius: 50%; width: 120px; height: 120px; animation: spin 2s linear infinite; } .carousel-3d-loader-circle > div { width: 100px; height: 100px; position: relative; -ms-animation: uil-rolling-anim 1s linear infinite; -moz-animation: uil-rolling-anim 1s linear infinite; -webkit-animation: uil-rolling-anim 1s linear infinite; -o-animation: uil-rolling-anim 1s linear infinite; animation: uil-rolling-anim 1s linear infinite; } .carousel-3d-loader-circle > div div { position: absolute; width: 100px; height: 50px; border-radius: 500px 500px 0 0; border-color: #000000; border-style: solid; border-width: 20px; border-bottom-width: 0; } .carousel-3d-loader-circle > div div:nth-of-type(2) { -ms-transform: translate(0, 25px) rotate(27deg) translate(0, -25px); -moz-transform: translate(0, 25px) rotate(27deg) translate(0, -25px); -webkit-transform: translate(0, 25px) rotate(27deg) translate(0, -25px); -o-transform: translate(0, 25px) rotate(27deg) translate(0, -25px); transform: translate(0, 25px) rotate(27deg) translate(0, -25px); } .carousel-3d-loader { position: relative; left: 46%; } .carousel-3d-loader-percentage, .carousel-3d-loader-error { font-size: 18px; position: absolute; top: 50%; text-align: center; left: 3.2%; margin-top: -9px; line-height: 18px; } "],
                providers: []
            },] },
];
/**
 * @nocollapse
 */
Ng2Carousel3dComponent.ctorParameters = function () { return []; };
Ng2Carousel3dComponent.propDecorators = {
    'options': [{ type: core.Input },],
    'slides': [{ type: core.Input },],
    'onBeforeChange': [{ type: core.Input },],
    'onLastSlide': [{ type: core.Input },],
    'onSlideChange': [{ type: core.Input },],
    'onSelectedClick': [{ type: core.Input },],
};

var Ng2Carousel3dSlideComponent = (function () {
    function Ng2Carousel3dSlideComponent() {
    }
    /**
     * @return {?}
     */
    Ng2Carousel3dSlideComponent.prototype.ngOnInit = function () {
    };
    return Ng2Carousel3dSlideComponent;
}());
Ng2Carousel3dSlideComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ng2-carousel-3d-slide',
                template: "<div class=\"slide-3d\"> <ng-content></ng-content> </div> ",
                styles: [".slide-3d { border-radius: 4px; border-color: #000; border-color: rgba(0, 0, 0, 0.4); border-style: solid; background-size: cover; height: 100%; } .slide-3d figure img { width: 100%; } .slide-3d figure figcaption { position: absolute; background: rgba(0, 0, 0, 0.5); color: #fff; width: 100%; left: 0; bottom: 0; font-weight: normal; text-align: center; padding: 7px 10px; } "]
            },] },
];
/**
 * @nocollapse
 */
Ng2Carousel3dSlideComponent.ctorParameters = function () { return []; };

var Ng2Carousel3dModule = (function () {
    function Ng2Carousel3dModule() {
    }
    return Ng2Carousel3dModule;
}());
Ng2Carousel3dModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule
                ],
                declarations: [
                    Ng2Carousel3dComponent,
                    Ng2Carousel3dSlideComponent
                ],
                exports: [
                    Ng2Carousel3dComponent,
                    Ng2Carousel3dSlideComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
Ng2Carousel3dModule.ctorParameters = function () { return []; };

exports.Ng2Carousel3dModule = Ng2Carousel3dModule;

Object.defineProperty(exports, '__esModule', { value: true });

})));
